use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Anwar
Any
Archive
BooK
Bruhat
Clint
MetaCPAN
Michael
Mohammad
Moore
Olaf
Philippe
Plugin
Schwern
Tar
Zip
author
book
current
emeritus
jenish
jenishg
lib
maintainer
mohammad
olaf
unknown
